@@ -60,7 +60,7 @@ class VelbusParser(object):
             if not result:
                 logging.warning("End byte not recognized")
             result = result and velbus.checksum(
-                self.buffer[0:packet_size - 2]) == self.buffer[packet_size - 2]
+                self.buffer[0:packet_size - 2])[0] == self.buffer[packet_size - 2]
             if not result:
                 logging.warning("Checksum not recognized")
         logging.debug("Valid Body Waiting: %s (%s)", result, str(self.buffer))
@@ -115,7 +115,7 @@ class VelbusParser(object):
             logging.warning(
                 "length of data size does not match actual length of message")
             return
-        if not velbus.checksum(data[:-2]) == data[-2]:
+        if not velbus.checksum(data[:-2])[0] == data[-2]:
             logging.warning("Packet has no valid checksum")
             return
         if data_size >= 1:
